package OurNet::BBS::CVIC::User;
$VERSION = "0.1";

use base qw/OurNet::BBS::MAPLE2::User/;
use fields qw/_ego _hash/;

use OurNet::BBS::Base;;

1;
